==> zio-aws-swf_3-5.17.145.1-sources.jar: zio/aws/swf/model/package.scala <==
package zio.aws.swf
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.swf.model.primitives.{Tag, ResourceTagKey}
import zio.aws.swf.model.primitives.Data.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ActivityId extends Subtype[String]
    type ActivityId = zio.aws.swf.model.primitives.ActivityId.Type
    object Arn extends Subtype[String]
    type Arn = zio.aws.swf.model.primitives.Arn.Type
    object Canceled extends Subtype[Boolean]
    type Canceled = zio.aws.swf.model.primitives.Canceled.Type
    object CauseMessage extends Subtype[String]
    type CauseMessage = zio.aws.swf.model.primitives.CauseMessage.Type
    object Count extends Subtype[Int]
    type Count = zio.aws.swf.model.primitives.Count.Type
    object Data extends Subtype[String]
    type Data = zio.aws.swf.model.primitives.Data.Type
    object Description extends Subtype[String]
    type Description = zio.aws.swf.model.primitives.Description.Type
    object DomainName extends Subtype[String]
    type DomainName = zio.aws.swf.model.primitives.DomainName.Type
    object DurationInDays extends Subtype[String]
    type DurationInDays = zio.aws.swf.model.primitives.DurationInDays.Type
    object DurationInSeconds extends Subtype[String]
    type DurationInSeconds = zio.aws.swf.model.primitives.DurationInSeconds.Type
    object DurationInSecondsOptional extends Subtype[String]
    type DurationInSecondsOptional =
      zio.aws.swf.model.primitives.DurationInSecondsOptional.Type
    object EventId extends Subtype[Long]
    type EventId = zio.aws.swf.model.primitives.EventId.Type
    object FailureReason extends Subtype[String]
    type FailureReason = zio.aws.swf.model.primitives.FailureReason.Type
    object FunctionId extends Subtype[String]
    type FunctionId = zio.aws.swf.model.primitives.FunctionId.Type
    object FunctionInput extends Subtype[String]
    type FunctionInput = zio.aws.swf.model.primitives.FunctionInput.Type
    object FunctionName extends Subtype[String]
    type FunctionName = zio.aws.swf.model.primitives.FunctionName.Type
    object Identity extends Subtype[String]
    type Identity = zio.aws.swf.model.primitives.Identity.Type
    object LimitedData extends Subtype[String]
    type LimitedData = zio.aws.swf.model.primitives.LimitedData.Type
    object MarkerName extends Subtype[String]
    type MarkerName = zio.aws.swf.model.primitives.MarkerName.Type
    object Name extends Subtype[String]
    type Name = zio.aws.swf.model.primitives.Name.Type
    object OpenDecisionTasksCount extends Subtype[Int]
    type OpenDecisionTasksCount =
      zio.aws.swf.model.primitives.OpenDecisionTasksCount.Type
    object PageSize extends Subtype[Int]
    type PageSize = zio.aws.swf.model.primitives.PageSize.Type
    object PageToken extends Subtype[String]
    type PageToken = zio.aws.swf.model.primitives.PageToken.Type
    object ResourceTagKey extends Subtype[String]
    type ResourceTagKey = zio.aws.swf.model.primitives.ResourceTagKey.Type
    object ResourceTagValue extends Subtype[String]
    type ResourceTagValue = zio.aws.swf.model.primitives.ResourceTagValue.Type
    object ReverseOrder extends Subtype[Boolean]
    type ReverseOrder = zio.aws.swf.model.primitives.ReverseOrder.Type
    object SignalName extends Subtype[String]
    type SignalName = zio.aws.swf.model.primitives.SignalName.Type
    object Tag extends Subtype[String]
    type Tag = zio.aws.swf.model.primitives.Tag.Type
    object TaskPriority extends Subtype[String]
    type TaskPriority = zio.aws.swf.model.primitives.TaskPriority.Type
    object TaskToken extends Subtype[String]
    type TaskToken = zio.aws.swf.model.primitives.TaskToken.Type
    object TerminateReason extends Subtype[String]
    type TerminateReason = zio.aws.swf.model.primitives.TerminateReason.Type
    object TimerId extends Subtype[String]
    type TimerId = zio.aws.swf.model.primitives.TimerId.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.swf.model.primitives.Timestamp.Type
    object Truncated extends Subtype[Boolean]
    type Truncated = zio.aws.swf.model.primitives.Truncated.Type
    object Version extends Subtype[String]
    type Version = zio.aws.swf.model.primitives.Version.Type
    object VersionOptional extends Subtype[String]
    type VersionOptional = zio.aws.swf.model.primitives.VersionOptional.Type
    object WorkflowId extends Subtype[String]
    type WorkflowId = zio.aws.swf.model.primitives.WorkflowId.Type
    object WorkflowRunId extends Subtype[String]
    type WorkflowRunId = zio.aws.swf.model.primitives.WorkflowRunId.Type
    object WorkflowRunIdOptional extends Subtype[String]
    type WorkflowRunIdOptional =
      zio.aws.swf.model.primitives.WorkflowRunIdOptional.Type
  }
  type ActivityTypeInfoList = List[zio.aws.swf.model.ActivityTypeInfo]
  type DecisionList = List[zio.aws.swf.model.Decision]
  type DomainInfoList = List[zio.aws.swf.model.DomainInfo]
  type HistoryEventList = List[zio.aws.swf.model.HistoryEvent]
  type ResourceTagKeyList = List[ResourceTagKey]
  type ResourceTagList = List[zio.aws.swf.model.ResourceTag]
  type TagList = List[Tag]
  type WorkflowExecutionInfoList = List[zio.aws.swf.model.WorkflowExecutionInfo]
  type WorkflowTypeInfoList = List[zio.aws.swf.model.WorkflowTypeInfo]
}

==> zio-aws-swf_3-6.20.78.2-sources.jar: zio/aws/swf/model/package.scala <==
package zio.aws.swf
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.swf.model.primitives.{Tag, ResourceTagKey}
import zio.aws.swf.model.primitives.Data.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ActivityId extends Subtype[String]
    type ActivityId = zio.aws.swf.model.primitives.ActivityId.Type
    object Arn extends Subtype[String]
    type Arn = zio.aws.swf.model.primitives.Arn.Type
    object Canceled extends Subtype[Boolean]
    type Canceled = zio.aws.swf.model.primitives.Canceled.Type
    object CauseMessage extends Subtype[String]
    type CauseMessage = zio.aws.swf.model.primitives.CauseMessage.Type
    object Count extends Subtype[Int]
    type Count = zio.aws.swf.model.primitives.Count.Type
    object Data extends Subtype[String]
    type Data = zio.aws.swf.model.primitives.Data.Type
    object Description extends Subtype[String]
    type Description = zio.aws.swf.model.primitives.Description.Type
    object DomainName extends Subtype[String]
    type DomainName = zio.aws.swf.model.primitives.DomainName.Type
    object DurationInDays extends Subtype[String]
    type DurationInDays = zio.aws.swf.model.primitives.DurationInDays.Type
    object DurationInSeconds extends Subtype[String]
    type DurationInSeconds = zio.aws.swf.model.primitives.DurationInSeconds.Type
    object DurationInSecondsOptional extends Subtype[String]
    type DurationInSecondsOptional =
      zio.aws.swf.model.primitives.DurationInSecondsOptional.Type
    object EventId extends Subtype[Long]
    type EventId = zio.aws.swf.model.primitives.EventId.Type
    object FailureReason extends Subtype[String]
    type FailureReason = zio.aws.swf.model.primitives.FailureReason.Type
    object FunctionId extends Subtype[String]
    type FunctionId = zio.aws.swf.model.primitives.FunctionId.Type
    object FunctionInput extends Subtype[String]
    type FunctionInput = zio.aws.swf.model.primitives.FunctionInput.Type
    object FunctionName extends Subtype[String]
    type FunctionName = zio.aws.swf.model.primitives.FunctionName.Type
    object Identity extends Subtype[String]
    type Identity = zio.aws.swf.model.primitives.Identity.Type
    object LimitedData extends Subtype[String]
    type LimitedData = zio.aws.swf.model.primitives.LimitedData.Type
    object MarkerName extends Subtype[String]
    type MarkerName = zio.aws.swf.model.primitives.MarkerName.Type
    object Name extends Subtype[String]
    type Name = zio.aws.swf.model.primitives.Name.Type
    object OpenDecisionTasksCount extends Subtype[Int]
    type OpenDecisionTasksCount =
      zio.aws.swf.model.primitives.OpenDecisionTasksCount.Type
    object PageSize extends Subtype[Int]
    type PageSize = zio.aws.swf.model.primitives.PageSize.Type
    object PageToken extends Subtype[String]
    type PageToken = zio.aws.swf.model.primitives.PageToken.Type
    object ResourceTagKey extends Subtype[String]
    type ResourceTagKey = zio.aws.swf.model.primitives.ResourceTagKey.Type
    object ResourceTagValue extends Subtype[String]
    type ResourceTagValue = zio.aws.swf.model.primitives.ResourceTagValue.Type
    object ReverseOrder extends Subtype[Boolean]
    type ReverseOrder = zio.aws.swf.model.primitives.ReverseOrder.Type
    object SignalName extends Subtype[String]
    type SignalName = zio.aws.swf.model.primitives.SignalName.Type
    object StartAtPreviousStartedEvent extends Subtype[Boolean]
    type StartAtPreviousStartedEvent =
      zio.aws.swf.model.primitives.StartAtPreviousStartedEvent.Type
    object Tag extends Subtype[String]
    type Tag = zio.aws.swf.model.primitives.Tag.Type
    object TaskPriority extends Subtype[String]
    type TaskPriority = zio.aws.swf.model.primitives.TaskPriority.Type
    object TaskToken extends Subtype[String]
    type TaskToken = zio.aws.swf.model.primitives.TaskToken.Type
    object TerminateReason extends Subtype[String]
    type TerminateReason = zio.aws.swf.model.primitives.TerminateReason.Type
    object TimerId extends Subtype[String]
    type TimerId = zio.aws.swf.model.primitives.TimerId.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.swf.model.primitives.Timestamp.Type
    object Truncated extends Subtype[Boolean]
    type Truncated = zio.aws.swf.model.primitives.Truncated.Type
    object Version extends Subtype[String]
    type Version = zio.aws.swf.model.primitives.Version.Type
    object VersionOptional extends Subtype[String]
    type VersionOptional = zio.aws.swf.model.primitives.VersionOptional.Type
    object WorkflowId extends Subtype[String]
    type WorkflowId = zio.aws.swf.model.primitives.WorkflowId.Type
    object WorkflowRunId extends Subtype[String]
    type WorkflowRunId = zio.aws.swf.model.primitives.WorkflowRunId.Type
    object WorkflowRunIdOptional extends Subtype[String]
    type WorkflowRunIdOptional =
      zio.aws.swf.model.primitives.WorkflowRunIdOptional.Type
  }
  type ActivityTypeInfoList = List[zio.aws.swf.model.ActivityTypeInfo]
  type DecisionList = List[zio.aws.swf.model.Decision]
  type DomainInfoList = List[zio.aws.swf.model.DomainInfo]
  type HistoryEventList = List[zio.aws.swf.model.HistoryEvent]
  type ResourceTagKeyList = List[ResourceTagKey]
  type ResourceTagList = List[zio.aws.swf.model.ResourceTag]
  type TagList = List[Tag]
  type WorkflowExecutionInfoList = List[zio.aws.swf.model.WorkflowExecutionInfo]
  type WorkflowTypeInfoList = List[zio.aws.swf.model.WorkflowTypeInfo]
}
